import os
from os.path import dirname, abspath, join
import environ


## TODO prob need to rework getting base dir if this becomes a pip package
# Build paths inside the project like this: os.path.join(BASE_DIR, ...)
BASE_DIR = dirname(dirname(dirname(dirname(abspath(__file__)))))

INSTALLED_APPS_BASE = [
    "channels",
    "django.contrib.admin",
    "django.contrib.auth",
    "django.contrib.contenttypes",
    "django.contrib.sessions",
    "django.contrib.messages",
    "django.contrib.staticfiles",
]

AUTH_USER_MODEL = "users.User"

MIDDLEWARE_BASE = [
    "django.middleware.security.SecurityMiddleware",
    "django.contrib.sessions.middleware.SessionMiddleware",
    "django.middleware.common.CommonMiddleware",
    #    "django.middleware.csrf.CsrfViewMiddleware",
    "django.contrib.auth.middleware.AuthenticationMiddleware",
    "django.contrib.messages.middleware.MessageMiddleware",
    "django.middleware.clickjacking.XFrameOptionsMiddleware",
    "apps.core.middleware.simple_middleware",
    'whitenoise.middleware.WhiteNoiseMiddleware',
]

MIDDLEWARE =  MIDDLEWARE_BASE + []

STATICFILES_STORAGE = 'whitenoise.storage.CompressedManifestStaticFilesStorage'

ROOT_URLCONF = "config.urls"

TEMPLATES = [
    {
        "BACKEND": "django.template.backends.django.DjangoTemplates",
        "DIRS": [os.path.join(BASE_DIR, "core", "templates")],
        "APP_DIRS": True,
        "OPTIONS": {
            "context_processors": [
                "django.template.context_processors.debug",
                "django.template.context_processors.request",
                "django.contrib.auth.context_processors.auth",
                "django.contrib.messages.context_processors.messages",
            ]
        },
    }
]

WSGI_APPLICATION = "config.wsgi.application"
ASGI_APPLICATION = "config.routing.application"

# Password validation
# https://docs.djangoproject.com/en/2.1/ref/settings/#auth-password-validators

AUTH_PASSWORD_VALIDATORS = [
    {
        "NAME": "django.contrib.auth.password_validation.UserAttributeSimilarityValidator"
    },
    {"NAME": "django.contrib.auth.password_validation.MinimumLengthValidator"},
    {"NAME": "django.contrib.auth.password_validation.CommonPasswordValidator"},
    {"NAME": "django.contrib.auth.password_validation.NumericPasswordValidator"},
]

# Internationalization
# https://docs.djangoproject.com/en/2.1/topics/i18n/

LANGUAGE_CODE = "en-us"

TIME_ZONE = "UTC"

USE_I18N = True

USE_L10N = True

USE_TZ = True

# Static files (CSS, JavaScript, Images)
# https://docs.djangoproject.com/en/2.1/howto/static-files/

STATIC_URL = "/static/"
STATIC_ROOT = BASE_DIR + "/static"

env = environ.Env(
    CONTEXT=(str, "dev"),
    DATABASE_URL=(str, 'sqlite:///sqlite.db'),
)

PROD = env("CONTEXT") == "prod"
DEV = env("CONTEXT") == "dev"

if DEV:
    # We should be able to run CONTEXT=build/test etc without .env file
    environ.Env.read_env(join(BASE_DIR, ".env"))
elif PROD:
    SECRET_KEY = env("SECRET_KEY")

if not PROD:
    DEBUG = True
    SECRET_KEY = "random_key_123"



from setuptools import setup

setup(
    name='rjango_core',
    version='0.1.3',
    description='Core utilities to enable minimal working Rjango style backends.',
    long_description='',
    author='Nicholas Romero',
    author_email='ncrmro@gmail.com',
    license='MIT License',
    packages=[
        'rjango.core',
        'rjango.core.settings'
    ],
    zip_safe=False,
    install_requires=[
        "django>=2",
        "channels>=2",
        "daphne>=2.2.5,<=2.3.0",
        "whitenoise>=4"
    ]
)
